# Changelog

## 0.0.8 (2021-03-24)

* Enhanced reporting capabilities
* Enhanced documentation
* Code spring-cleaning
* Better test coverage
* Eighth release on PyPI

## 0.0.7 (2021-03-23)

* Updated CSAF Schema draft to 2021.03.23 (default)
* 2021.03.19 still available per `csaf_lint/schema/csaf/2021.03.19/csaf.json`
* Changed logging concept (removed print style debug statements)
* Seventh release on PyPI

## 0.0.6 (2021-03-22)

* Added meta data and harmonized packaging
* Sixth release on PyPI

## 0.0.5 (2021-03-22)

* Enhanced PyPI documentation (project links)
* Fifth release on PyPI

##  0.0.4 (2021-03-22)

* Updated CSAF Schema draft to 2021.03.19 (default)
* 2021.03.07 still available per `csaf_lint/schema/csaf/2021.03.07/csaf.json`
* Updated user documentation
* Fourth release on PyPI

## 0.0.3 (2021-03-21)

* Validation implemented for CSAF (CVRF) versions 1.1 and 1.2
* Implemented further CLI and linter tests
* Created user documentation for install and usage
* Third release on PyPI

## 0.0.2 (2021-03-19)

* Validation implemented as per CSAF draft 2021.03.07 schema
* Added the CSAF draft 2021.03.07 schema
* Implemented initial CLI and linter tests
* Created corpus of baseline and invalid documents for test
* Second release on PyPI

## 0.0.1 (2021-03-10)

* First release on PyPI
